#!/usr/bin/env python

import os
import re

from setuptools import setup, find_packages


def find_version(*segments):
    root = os.path.abspath(os.path.dirname(__file__))
    abspath = os.path.join(root, *segments)
    with open(abspath, "r") as file:
        content = file.read()
    match = re.search(r"^__version__ = ['\"]([^'\"]+)['\"]", content, re.MULTILINE)
    if match:
        return match.group(1)
    raise RuntimeError("Unable to find version string!")


setup(
    author="Richard Davis",
    author_email="crashvb@gmail.com",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Operating System :: OS Independent",
    ],
    description="Provides asynchronous temporary files.",
    extras_require={
        "dev": [
            "black",
            "coveralls",
            "pylint",
            "pytest",
            "pytest-asyncio",
            "twine",
            "wheel",
        ]
    },
    include_package_data=True,
    install_requires=["aiofiles"],
    keywords="aio aiotempfile async asynchronous file files temp temporary",
    license="Apache License 2.0",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    name="aiotempfile",
    packages=find_packages(),
    project_urls={
        "Bug Reports": "https://github.com/crashvb/aiotempfile/issues",
        "Source": "https://github.com/crashvb/aiotempfile",
    },
    tests_require=["pytest", "pytest-asyncio"],
    test_suite="tests",
    url="https://github.com/crashvb/aiotempfile",
    version=find_version("aiotempfile", "__init__.py"),
)
